==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/CUESTIMATECOMPATIBLEUNITID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUESTIMATECOMPATIBLEUNITID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUESTIMATECOMPATIBLEUNITID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUESTIMATEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUESTIMATECOMPATIBLEUNITID_Type", propOrder = {
    "cuestimateid",
    "sequencenumber"
})
public class CUESTIMATECOMPATIBLEUNITID_Type {

    @XmlElement(name = "CUESTIMATEID", required = true)
    protected STANDARDENTITYID_Type cuestimateid;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Gets the value of the cuestimateid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getCUESTIMATEID() {
        return cuestimateid;
    }

    /**
     * Sets the value of the cuestimateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setCUESTIMATEID(STANDARDENTITYID_Type value) {
        this.cuestimateid = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/CUESTIMATECOMPATIBLEUNITID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUESTIMATECOMPATIBLEUNITID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="CUESTIMATECOMPATIBLEUNITID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUESTIMATEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUESTIMATECOMPATIBLEUNITID_Type", propOrder = {
    "cuestimateid",
    "sequencenumber"
})
public class CUESTIMATECOMPATIBLEUNITID_Type {

    @XmlElement(name = "CUESTIMATEID", required = true)
    protected STANDARDENTITYID_Type cuestimateid;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;

    /**
     * Gets the value of the cuestimateid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getCUESTIMATEID() {
        return cuestimateid;
    }

    /**
     * Sets the value of the cuestimateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setCUESTIMATEID(STANDARDENTITYID_Type value) {
        this.cuestimateid = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

}
